Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1300)

Unified Diff: chrome/browser/net/chrome_url_request_context.h

Issue 501082: Implement delaying resource requests until privacy blacklists are ready. (Closed)
Patch Set: don't get stuck on errors Created 10 years, 12 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/app/generated_resources.grd ('k') | chrome/browser/net/chrome_url_request_context.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/net/chrome_url_request_context.h
diff --git a/chrome/browser/net/chrome_url_request_context.h b/chrome/browser/net/chrome_url_request_context.h
index 060626e6811c309e915422161fa4e93446b187fc..b8ae7040c83e25721da0e585abf0714e550a6580 100644
--- a/chrome/browser/net/chrome_url_request_context.h
+++ b/chrome/browser/net/chrome_url_request_context.h
@@ -13,7 +13,6 @@
#include "chrome/common/pref_service.h"
#include "net/url_request/url_request_context.h"
-class Blacklist;
class BlacklistManager;
class CommandLine;
class Profile;
@@ -192,8 +191,8 @@ class ChromeURLRequestContext : public URLRequestContext {
const HostZoomMap* host_zoom_map() const { return host_zoom_map_; }
- // Gets the Privacy Blacklist, if any for this context.
- const Blacklist* GetBlacklist() const;
+ // Gets the Privacy Blacklist Manager, if any for this context.
+ BlacklistManager* GetBlacklistManager() const;
// Callback for when new extensions are loaded.
void OnNewExtensions(const std::string& id,
« no previous file with comments | « chrome/app/generated_resources.grd ('k') | chrome/browser/net/chrome_url_request_context.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698